<?php

declare(strict_types = 1);

namespace Drupal\ui_suite_bootstrap\HookHandler;

/**
 * Handle variables needed for the pattern.
 */
class PreprocessPatternFigure {

  /**
   * Handle variables needed for the pattern.
   *
   * @param array $variables
   *   The preprocessed variables.
   */
  public function preprocess(array &$variables): void {
    if (!\array_key_exists('image', $variables) || !\is_array($variables['image'])) {
      return;
    }

    foreach ($variables['image'] as &$item) {
      $this->addImageClass($item, 'figure-img');
    }
  }

  /**
   * Add class to figure's image.
   *
   * @param mixed $item
   *   A render item.
   * @param string $image_class
   *   The image class to add.
   */
  protected function addImageClass(&$item, string $image_class): void {
    if (!\is_array($item)) {
      return;
    }

    if (\array_key_exists('#theme', $item)) {
      if ($item['#theme'] === 'image') {
        $item['#attributes']['class'][] = $image_class;
      }
      if ($item['#theme'] === 'image_formatter') {
        $item['#item_attributes']['class'][] = $image_class;
      }
    }

    foreach ($item as &$next) {
      $this->addImageClass($next, $image_class);
    }
  }

}
